==> cramr_ui_lib-1.0.7.tar.gz: test/routes/multi_conjugation_verb_selection_route_test.dart <==
import 'dart:math';

import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('Basic test of multi conjugation selection route',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
            'fr', 'translation', _mode, _tense);
        int i = 0;
        for (var element in _randomIndicative) {
          model.add(element, i++);
        }
        return model;
      },
      child: MaterialApp(
        home: MultiConjugationVerbSelectionRoute(
            SettingsController(SettingsService(prefs), ThemeMode.dark, prefs)),
      ),
    ));
    Finder centerFinder = find.byKey(const Key('verbSelectionCenter'));
    expect(centerFinder, findsOneWidget);
    Finder listViewFinder = find.byKey(const Key('verbListView'));
    expect(listViewFinder, findsOneWidget);
    Finder playButtonsFinder = find.byType(Icon);
    expect(playButtonsFinder, findsWidgets);
  });
}

==> cramr_ui_lib-1.0.8.tar.gz: test/routes/multi_conjugation_verb_selection_route_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('Basic test of multi conjugation selection route',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
            'fr', 'translation', _mode, _tense);
        int i = 0;
        for (var element in _randomIndicative) {
          model.add(element, i++);
        }
        return model;
      },
      child: MaterialApp(
        home: MultiConjugationVerbSelectionRoute(SettingsController(
            SettingsService(prefs), ThemeMode.dark, prefs)),
      ),
    ));
    Finder centerFinder = find.byKey(const Key('verbSelectionCenter'));
    expect(centerFinder, findsOneWidget);
    Finder listViewFinder = find.byKey(const Key('verbListView'));
    expect(listViewFinder, findsOneWidget);
    Finder playButtonsFinder = find.byType(Icon);
    expect(playButtonsFinder, findsWidgets);
  });
}
